@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2014 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2015 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -796,6 +796,9 @@ class PodcastListModel(gtk.ListStore):
             del self._cover_cache[podcast_url]
 
     def add_cover_by_channel(self, channel, pixbuf):
+        # Remove older images from cache
+        self.clear_cover_cache(channel.url)
+
         # Resize and add the new cover image
         pixbuf = self._resize_pixbuf(channel.url, pixbuf)
         if channel.pause_subscription:
