@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2014 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2015 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -78,6 +78,10 @@ formats = [
 ]
 formats_dict = dict(formats)
 
+V3_API_ENDPOINT = 'https://www.googleapis.com/youtube/v3'
+CHANNEL_VIDEOS_XML = 'https://www.youtube.com/feeds/videos.xml'
+
+
 class YouTubeError(Exception): pass
 
 
@@ -185,9 +189,10 @@ def for_each_feed_pattern(func, url, fallback_result):
     CHANNEL_MATCH_PATTERNS = [
         'http[s]?://(?:[a-z]+\.)?youtube\.com/user/([a-z0-9]+)',
         'http[s]?://(?:[a-z]+\.)?youtube\.com/profile?user=([a-z0-9]+)',
-        'http[s]?://(?:[a-z]+\.)?youtube\.com/channel/([a-z0-9]+)',
+        'http[s]?://(?:[a-z]+\.)?youtube\.com/channel/([_a-z0-9]+)',
         'http[s]?://(?:[a-z]+\.)?youtube\.com/rss/user/([a-z0-9]+)/videos\.rss',
         'http[s]?://gdata.youtube.com/feeds/users/([^/]+)/uploads',
+        'http[s]?://(?:[a-z]+\.)?youtube\.com/feeds/videos.xml?channel_id=([a-z0-9]+)',
     ]
 
     for pattern in CHANNEL_MATCH_PATTERNS:
@@ -201,7 +206,7 @@ def for_each_feed_pattern(func, url, fallback_result):
 
 def get_real_channel_url(url):
     def return_user_feed(url, channel):
-        result = 'https://gdata.youtube.com/feeds/users/{}/uploads'.format(channel)
+        result = 'https://gdata.youtube.com/feeds/users/{0}/uploads'.format(channel)
         logger.debug('YouTube link resolved: %s => %s', url, result)
         return result
 
@@ -209,7 +214,7 @@ def get_real_channel_url(url):
 
 def get_real_cover(url):
     def return_user_cover(url, channel):
-        api_url = 'http://gdata.youtube.com/feeds/api/users/{}?v=2'.format(channel)
+        api_url = 'http://gdata.youtube.com/feeds/api/users/{0}?v=2'.format(channel)
         data = util.urlopen(api_url).read()
         m = re.search('<media:thumbnail url=[\'"]([^\'"]+)[\'"]/>', data)
         if m is not None:
@@ -219,3 +224,22 @@ def get_real_cover(url):
         return None
 
     return for_each_feed_pattern(return_user_cover, url, None)
+
+def get_channels_for_user(username, api_key_v3):
+    stream = util.urlopen('{0}/channels?forUsername={1}&part=id&key={2}'.format(V3_API_ENDPOINT, username, api_key_v3))
+    data = json.load(stream)
+    return ['{0}?channel_id={1}'.format(CHANNEL_VIDEOS_XML, item['id']) for item in data['items']]
+
+
+def resolve_v3_url(url, api_key_v3):
+    # Check if it's a YouTube feed, and if we have an API key, auto-resolve the channel
+    if url and api_key_v3:
+        _, user = for_each_feed_pattern(lambda url, channel: (url, channel), url, (None, None))
+        if user is not None:
+            logger.info('Getting channels for YouTube user %s', user)
+            new_urls = get_channels_for_user(user, api_key_v3)
+            logger.debug('YouTube channels retrieved: %r', new_urls)
+            if len(new_urls) == 1:
+                return new_urls[0]
+
+    return url
